##  Managing Architecture Decisions
Users with appropriate permissions can manage architecture decisions on the Architecture Decisions page. Here, you can:
  * Edit decisions: You can edit decisions in any status, which enables you to modify relevant information at any stage of the decision-making process.
  * Change the decision status: You can change the decision status at any time, which allows flexibility in the decision-making process.
  * Duplicate decisions: Duplicating an existing decision can save time, especially when you need to create multiple decisions with similar content. To duplicate a decision, hover over it, then click the duplicate icon that appears on the right.
  * Delete decisions: If needed, you can delete duplicate or irrelevant decisions. When deleting decisions, proceed with caution. This action cannot be undone.


![Decisions list in SAP LeanIX showing decision titles, statuses, and creators.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio6b8945941fa342ddb0d05506e6a954ce_LowRes.png)
Architecture Decisions
